
API
===

.. currentmodule:: footings

Core
----

Functions
~~~~~~~~~

.. autosummary::
   :nosignatures:

   create_argument
   use
   create_model
   create_dispatch_function
   create_loaded_function

|
|

.. autofunction:: create_argument
.. autofunction:: use
.. autofunction:: create_model
.. autofunction:: create_dispatch_function
.. autofunction:: create_loaded_function


Classes
~~~~~~~
.. autosummary::
   :nosignatures:

   footings.core.argument.Argument
   footings.core.footing.Dependent
   footings.core.model.BaseModel
   footings.core.utils.DispatchFunction
   footings.core.utils.LoadedFunction

|
|


.. autoclass:: footings.core.argument.Argument
   :members:

.. autoclass:: footings.core.footing.Dependent
   :members:

.. autoclass:: footings.core.model.BaseModel
   :members:

.. autoclass:: footings.core.utils.DispatchFunction
   :members:

.. autoclass:: footings.core.utils.LoadedFunction
   :members:

Library
-------

.. currentmodule:: footings.library

.. autosummary::
   :nosignatures:

   create_frame
   create_frame_from_record
   expand_frame_per_record
   calculate_age
   post_drop_columns

|
|

.. autofunction:: create_frame
.. autofunction:: create_frame_from_record
.. autofunction:: expand_frame_per_record
.. autofunction:: calculate_age
.. autofunction:: post_drop_columns
